# **:- Change Log -:**

> **0.0.1** -- [ 11 APRIL 2023 ]  
> [ NOTICE ]  
> [ ! ] - Initial Release

> **0.0.2 - 0.0.5**  
> [ INFO ]  
> [+] Upload and Import Error

> **0.0.6** -- [ 11 APRIL 2023 ]  
> [ NOTICE ]  
> [+] Module Install fixed

> **0.0.7** -- [ 25 APRIL 2023 ]  
> [ ADDED ]  
> [+] Cursor change on titlebar drag  
> [+] Get window detailes  
> [+] Persistent styling  
> [+] Custom window widget spacing
> [+] Custom window margin
>
> [ FIXED ]  
> [+] Extra space between widgets  
> [+] Custom Titlebar  
> [+] Window glitch using "Titlebar" element, "add" > and "update" method
>
> [ REMOVED ]  
> [+] Clera default titlebar style

> **0.0.8** -- [ 04 JULY 2023 ]  
> [ ADDED ]  
> [+] Extra controls of Window  
> [+] Stack Element for multi page development  
> [+] Extraction, Styling and Linking of Textarea scrollbar  
> [+] Wordwrap for Textarea  
> [+] Popup Window lock
>
> [ FIXED ]  
> [+] Windows style control icon  
> [+] Fusion style control icon  
> [+] File Element filter definition error
>
> [ CHANGED ]  
> [+] Default window spacing and content margin  
> [+] Stylesheet linking extension. Now only useds ".cx" extension

> **0.1.0** -- [ 11 JULY 2023 ]  
> [ ADDED ]  
> [+] Quick argument values  
> [+] Clera Style Editor
>
> [ CHANGED ]  
> [+] sizepolicy declaration
>
> [ FIXED ]  
> [+] ModuleNotFoundError: No module named 'clera.stubs'  
> [+] Window icon display  
> [+] AttributeError: 'MainWindow' object has no attribute 'old_position'
